@@ -14,10 +14,7 @@ namespace libboardgame_base {
 
 ostream& operator<<(ostream& out, CoordPoint p)
 {
-    if (! p.is_null())
-        out << '(' << p.x << ',' << p.y << ')';
-    else
-        out << "NULL";
+    out << '(' << p.x << ',' << p.y << ')';
     return out;
 }
 
