@@ -20,10 +20,6 @@ class TreeReader
     : public Reader
 {
 public:
-    TreeReader();
-
-    ~TreeReader() override;
-
     void on_begin_tree(bool is_root) override;
 
     void on_end_tree(bool is_root) override;
@@ -38,7 +34,7 @@ public:
     const SgfNode& get_tree() const { return *m_root; }
 
     /** Get the tree and transfer the ownership to the caller. */
-    unique_ptr<SgfNode> get_tree_transfer_ownership();
+    unique_ptr<SgfNode> move_tree();
 
 private:
     SgfNode* m_current = nullptr;
