@@ -67,9 +67,6 @@ public:
                 size_t min_simulations, double max_time,
                 TimeSource& time_source);
 
-    /** Get color to play at root node of the last search. */
-    Color get_to_play() const;
-
     const History& get_last_history() const;
 
     /** Get board position of last search at root node as setup.
@@ -126,11 +123,6 @@ inline PlayerInt Search::get_player() const
     return to_play;
 }
 
-inline Color Search::get_to_play() const
-{
-    return m_to_play;
-}
-
 inline void Search::set_avoid_symmetric_draw(bool enable)
 {
     m_shared_const.avoid_symmetric_draw = enable;
