@@ -14,14 +14,11 @@
 #include <QCoreApplication>
 #include <QHash>
 #include <QImage>
+#include <QUrl>
 #include <QVariant>
 #include <QtCore/private/qandroidextras_p.h>
 #include <QJniObject>
 
-#else
-
-#include <QStandardPaths>
-
 #endif
 
 using namespace std;
@@ -58,7 +55,7 @@ QJniObject getContentResolver()
                 "getContentResolver", "()Landroid/content/ContentResolver;");
 }
 
-QString getDisplayName(QJniObject uri)
+QString getDisplayName(const QJniObject& uri)
 {
     auto contentResolver = getContentResolver();
     if (! contentResolver.isValid())
@@ -124,7 +121,6 @@ void setExtraInitialUri(QJniObject& intent, const QString& uri)
 void startDocumentActivity(
         const char* actionField, const QString& type,
         const QString& extraInitialUri, const QString& extraTitle,
-        bool takePersistablePermission,
         const function<void(const QString& uri,const QString& displayNamei)>&
         callback)
 {
@@ -166,8 +162,7 @@ void startDocumentActivity(
         setExtraInitialUri(intent, extraInitialUri);
     QtAndroidPrivate::startActivity(
                 intent, 0,
-                [takePersistablePermission, callback](int, int result,
-                const QJniObject& data) {
+                [callback](int, int result, const QJniObject& data) {
         auto ok = QJniObject::getStaticField<jint>(
                     "android/app/Activity", "RESULT_OK");
         if (result != ok)
@@ -181,8 +176,7 @@ void startDocumentActivity(
                 uri.callObjectMethod("toString", "()Ljava/lang/String;");
         if (! uriString.isValid())
             return;
-        if (takePersistablePermission)
-            takePersistableUriPermission(uri);
+        takePersistableUriPermission(uri);
         auto displayName = getDisplayName(uri);
         callback(uriString.toString(), displayName);
     });
@@ -439,19 +433,17 @@ void AndroidUtils::openImageSaveDialog(
 {
 #ifdef Q_OS_ANDROID
     startDocumentActivity("ACTION_CREATE_DOCUMENT", "image/png",
-                          "", suggestedName, false,
+                          "", suggestedName,
                           [this](const QString& uri,
                           [[maybe_unused]]const QString& displayName) {
         emit imageSaveDialogAccepted(uri);
     });
 #endif
 }
-
 void AndroidUtils::openOpenDialog([[maybe_unused]] const QString& suggestedUri)
 {
 #ifdef Q_OS_ANDROID
     startDocumentActivity("ACTION_OPEN_DOCUMENT", "*/*", suggestedUri, "",
-                          true,
                           [this](const QString& uri,
                           const QString& displayName) {
         emit openDialogAccepted(uri, displayName);
@@ -459,25 +451,13 @@ void AndroidUtils::openOpenDialog([[maybe_unused]] const QString& suggestedUri)
 #endif
 }
 
-void AndroidUtils::openTextSaveDialog()
-{
-#ifdef Q_OS_ANDROID
-    startDocumentActivity("ACTION_CREATE_DOCUMENT", "text/plain", "", "",
-                          false,
-                          [this](const QString& uri,
-                          [[maybe_unused]]const QString& displayName) {
-        emit textSaveDialogAccepted(uri);
-    });
-#endif
-}
-
 void AndroidUtils::openSaveDialog(
         [[maybe_unused]] const QString& suggestedUri,
         [[maybe_unused]] const QString& suggestedName)
 {
 #ifdef Q_OS_ANDROID
     startDocumentActivity("ACTION_CREATE_DOCUMENT", "application/x-blokus-sgf",
-                          suggestedUri, suggestedName, true,
+                          suggestedUri, suggestedName,
                           [this](const QString& uri,
                           const QString& displayName) {
         emit saveDialogAccepted(uri, displayName);
