@@ -8,6 +8,8 @@
 #define PENTOBI_DOCBOOK_READER_H
 
 #include <QObject>
+#include <QDomDocument>
+#include <QtQml/qqmlregistration.h>
 
 using namespace Qt::StringLiterals;
 
@@ -24,6 +26,7 @@ class DocbookReader
     : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
 
     Q_PROPERTY(QString pageId MEMBER m_pageId WRITE setPageId)
     Q_PROPERTY(QString text READ text NOTIFY textChanged)
@@ -64,15 +67,27 @@ private:
 
     QString m_navigationText;
 
-    QString m_fileName;
+    QString m_locale;
+
+    QString m_lang;
 
     QStringList m_pageIds;
 
+    QDomDocument m_doc;
+
+
+    QDomElement findLocalized(const QDomElement& elem) const;
 
     QString getPage(const QString& id) const;
 
     QString getTableOfContents() const;
 
+    void handleChildren(const QDomNode& node, int headerLevel,
+                        QString& text) const;
+
+    QDomNode handleNode(const QDomNode& node, int headerLevel,
+                        QString& text) const;
+
     void setNavigation();
 
     void setText();
