@@ -8,6 +8,8 @@
 #define PENTOBI_RECENT_FILES_H
 
 #include <QObject>
+#include <QVariant>
+#include <QtQml/qqmlregistration.h>
 
 //-----------------------------------------------------------------------------
 
@@ -15,6 +17,7 @@ class RecentFiles
     : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
 
     Q_PROPERTY(QVariantList entries READ entries NOTIFY entriesChanged)
 
