@@ -500,223 +500,10 @@
 </context>
 <context>
     <name>Main</name>
-    <message>
-        <source>Pentobi</source>
-        <extracomment>Window title if no file is loaded.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Game analysis is only possible in main variation.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Your rating has increased from %1 to %2.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Your rating has decreased from %1 to %2.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Your rating stays at %1.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Delete all rating information for the current game variant?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Delete all variations?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Save failed.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>End of tree was reached. Continue search from start of the tree?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>No comment found</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>%1 (modified)</source>
-        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>File has been modified by another application. Reload?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Keep only position?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Keep only subtree?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open failed.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start rated game with Purple against Pentobi level %1?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start rated game with Green against Pentobi level %1?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start rated game with Blue against Pentobi level %1?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start rated game with Orange against Pentobi level %1?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start rated game with Yellow against Pentobi level %1?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start rated game with Red against Pentobi level %1?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>You have not yet played rated games in this game variant.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Truncate this subtree?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Truncate children?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Discard game?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Pentobi %1 (level %2)</source>
-        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Human</source>
-        <extracomment>Player name for game info in rated game.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rated game</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>File has been modified by another application. Overwrite?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>%1 - Pentobi</source>
-        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Not enough memory</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Game analysis aborted</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Computer move aborted</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rating information deleted</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Variations deleted</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>File saved</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Saving image failed or unsupported image format</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Image saved</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Creating image failed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Continuing rated game</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Kept only position</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Kept only subtree</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Variation is now %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Children truncated</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Setup</source>
-        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Setup Mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rated</source>
-        <extracomment>Label for ongoing rated game</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rated %1</source>
-        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rated Game %1</source>
-        <extracomment>Label for rated game. The argument is the game number.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Main Variation</source>
         <translation type="unfinished"></translation>
@@ -799,50 +586,10 @@
         <source>Undo Move</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Blue/Red</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Purple</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Green</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Blue</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Yellow/Green</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Orange</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Yellow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Red</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Pentobi failed to generate a move.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Press back again to exit</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Untitled.blksgf</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MenuComputer</name>
@@ -1284,6 +1031,259 @@
 </context>
 <context>
     <name>main</name>
+    <message>
+        <source>Pentobi</source>
+        <extracomment>Window title if no file is loaded.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Game analysis is only possible in main variation.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your rating has increased from %1 to %2.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your rating has decreased from %1 to %2.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your rating stays at %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete all rating information for the current game variant?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete all variations?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save failed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End of tree was reached. Continue search from start of the tree?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No comment found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 (modified)</source>
+        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File has been modified by another application. Reload?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keep only position?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keep only subtree?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open failed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start rated game with Purple against Pentobi level %1?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start rated game with Green against Pentobi level %1?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start rated game with Blue against Pentobi level %1?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start rated game with Orange against Pentobi level %1?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start rated game with Yellow against Pentobi level %1?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start rated game with Red against Pentobi level %1?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have not yet played rated games in this game variant.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Truncate this subtree?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Truncate children?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Discard game?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pentobi %1 (level %2)</source>
+        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Human</source>
+        <extracomment>Player name for game info in rated game.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rated game</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File has been modified by another application. Overwrite?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 - Pentobi</source>
+        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Game analysis aborted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Computer move aborted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rating information deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Variations deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File saved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Saving image failed or unsupported image format</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image saved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Creating image failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continuing rated game</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Kept only position</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Kept only subtree</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Variation is now %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Children truncated</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Setup</source>
+        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Setup Mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rated</source>
+        <extracomment>Label for ongoing rated game</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rated %1</source>
+        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rated Game %1</source>
+        <extracomment>Label for rated game. The argument is the game number.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Blue/Red</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Purple</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Green</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Blue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yellow/Green</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Orange</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yellow</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Red</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pentobi failed to generate a move.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Untitled.blksgf</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>computer opponent for the board game Blokus</source>
         <translation type="unfinished"></translation>
@@ -1348,5 +1348,14 @@
         <source>Too many arguments</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Use layout optimized for desktop.</source>
+        <extracomment>Description for command line option --desktop</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--mobile and --desktop cannot be used both</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
