@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="zh_CN">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -12,7 +14,7 @@
     </message>
     <message>
         <source>Computer opponent for Blokus</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -175,17 +177,17 @@
     <message>
         <source>Previous</source>
         <extracomment>Go to previous page of user manual</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Contents</source>
         <extracomment>Go to table of contents of user manual</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Next</source>
         <extracomment>Go to next page of user manual</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -196,7 +198,7 @@
     </message>
     <message>
         <source>Untitled.png</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -463,7 +465,7 @@
     <name>HelpWindow</name>
     <message>
         <source>Pentobi Help</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished">Pentobi 帮助</translation>
     </message>
 </context>
 <context>
@@ -498,223 +500,10 @@
 </context>
 <context>
     <name>Main</name>
-    <message>
-        <source>Pentobi</source>
-        <extracomment>Window title if no file is loaded.</extracomment>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Game analysis is only possible in main variation.</source>
-        <translation>棋局分析只能在主变化中进行。</translation>
-    </message>
-    <message>
-        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
-        <translation>自动保存的棋局被另一个程序实例更改。要覆盖吗？</translation>
-    </message>
-    <message>
-        <source>Your rating has increased from %1 to %2.</source>
-        <translation>您的等级从%1升到%2。</translation>
-    </message>
-    <message>
-        <source>Your rating has decreased from %1 to %2.</source>
-        <translation>您的等级从%1降到%2。</translation>
-    </message>
-    <message>
-        <source>Your rating stays at %1.</source>
-        <translation>您的等级仍然是%1。</translation>
-    </message>
-    <message>
-        <source>Delete all rating information for the current game variant?</source>
-        <translation>删除此游戏规则下的所有等级数据？</translation>
-    </message>
-    <message>
-        <source>Delete all variations?</source>
-        <translation>删除所有变例？</translation>
-    </message>
-    <message>
-        <source>Save failed.</source>
-        <translation>保存失败。</translation>
-    </message>
-    <message>
-        <source>End of tree was reached. Continue search from start of the tree?</source>
-        <translation>已经到达棋局树的最末端。从树的开头继续搜索？</translation>
-    </message>
-    <message>
-        <source>No comment found</source>
-        <translation>无注解</translation>
-    </message>
-    <message>
-        <source>%1 (modified)</source>
-        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
-        <translation>%1 （已修改）</translation>
-    </message>
-    <message>
-        <source>File has been modified by another application. Reload?</source>
-        <translation>文件被其他程序修改。重新加载吗？</translation>
-    </message>
-    <message>
-        <source>Keep only position?</source>
-        <translation>只保留棋子位置吗？</translation>
-    </message>
-    <message>
-        <source>Keep only subtree?</source>
-        <translation>只保留子树吗？</translation>
-    </message>
-    <message>
-        <source>Open failed.</source>
-        <translation>打开失败。</translation>
-    </message>
-    <message>
-        <source>Start rated game with Purple against Pentobi level %1?</source>
-        <translation>是否开始等级赛，你执紫色，对阵级别%1的电脑？</translation>
-    </message>
-    <message>
-        <source>Start rated game with Green against Pentobi level %1?</source>
-        <translation>是否开始等级赛，你执绿色，对阵级别%1的电脑？</translation>
-    </message>
-    <message>
-        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
-        <translation>是否开始等级赛，你执蓝/红，对阵级别%1的电脑？</translation>
-    </message>
-    <message>
-        <source>Start rated game with Blue against Pentobi level %1?</source>
-        <translation>是否开始等级赛，你执蓝色，对阵级别%1的电脑？</translation>
-    </message>
-    <message>
-        <source>Start rated game with Orange against Pentobi level %1?</source>
-        <translation>是否开始等级赛，你执橙色，对阵级别%1的电脑？</translation>
-    </message>
-    <message>
-        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
-        <translation>是否开始等级赛，你执黄/绿，对阵级别%1的电脑？</translation>
-    </message>
-    <message>
-        <source>Start rated game with Yellow against Pentobi level %1?</source>
-        <translation>是否开始等级赛，你执黄色，对阵级别%1的电脑？</translation>
-    </message>
-    <message>
-        <source>Start rated game with Red against Pentobi level %1?</source>
-        <translation>是否开始等级赛，你执红色，对阵级别%1的电脑？</translation>
-    </message>
-    <message>
-        <source>You have not yet played rated games in this game variant.</source>
-        <translation>在此规则下，您还没有玩过等级赛。</translation>
-    </message>
-    <message>
-        <source>Truncate this subtree?</source>
-        <translation>截断此子树？</translation>
-    </message>
-    <message>
-        <source>Truncate children?</source>
-        <translation>截断此结点下面的子结点？</translation>
-    </message>
-    <message>
-        <source>Discard game?</source>
-        <translation>丢弃本局吗？</translation>
-    </message>
-    <message>
-        <source>Pentobi %1 (level %2)</source>
-        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
-        <translation>Pentobi 版本%1（级别%2）</translation>
-    </message>
-    <message>
-        <source>Human</source>
-        <extracomment>Player name for game info in rated game.</extracomment>
-        <translation>人脑</translation>
-    </message>
-    <message>
-        <source>Rated game</source>
-        <translation>等级赛</translation>
-    </message>
-    <message>
-        <source>File has been modified by another application. Overwrite?</source>
-        <translation>文件已被其他程序修改。覆盖吗？</translation>
-    </message>
-    <message>
-        <source>%1 - Pentobi</source>
-        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Not enough memory</source>
         <translation>内存不足</translation>
     </message>
-    <message>
-        <source>Game analysis aborted</source>
-        <translation>棋局分析被取消</translation>
-    </message>
-    <message>
-        <source>Computer move aborted</source>
-        <translation>电脑行棋被取消</translation>
-    </message>
-    <message>
-        <source>Rating information deleted</source>
-        <translation>等级数据已删除</translation>
-    </message>
-    <message>
-        <source>Variations deleted</source>
-        <translation>变例已删除</translation>
-    </message>
-    <message>
-        <source>File saved</source>
-        <translation>文件已保存</translation>
-    </message>
-    <message>
-        <source>Saving image failed or unsupported image format</source>
-        <translation>图像保存失败，或不支持的图像格式</translation>
-    </message>
-    <message>
-        <source>Image saved</source>
-        <translation>图像已保存</translation>
-    </message>
-    <message>
-        <source>Creating image failed</source>
-        <translation>图像创建失败</translation>
-    </message>
-    <message>
-        <source>Continuing rated game</source>
-        <translation>继续等级赛</translation>
-    </message>
-    <message>
-        <source>Kept only position</source>
-        <translation>只保留棋子位置</translation>
-    </message>
-    <message>
-        <source>Kept only subtree</source>
-        <translation>只保留子树</translation>
-    </message>
-    <message>
-        <source>Variation is now %1</source>
-        <translation>当前变例为 %1</translation>
-    </message>
-    <message>
-        <source>Children truncated</source>
-        <translation>子结点已截断</translation>
-    </message>
-    <message>
-        <source>Setup</source>
-        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
-        <translation>设置模式</translation>
-    </message>
-    <message>
-        <source>Setup Mode</source>
-        <translation>设置模式</translation>
-    </message>
-    <message>
-        <source>Rated</source>
-        <extracomment>Label for ongoing rated game</extracomment>
-        <translation>等级赛</translation>
-    </message>
-    <message>
-        <source>Rated %1</source>
-        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
-        <translation>等级赛 第%1局</translation>
-    </message>
-    <message>
-        <source>Rated Game %1</source>
-        <extracomment>Label for rated game. The argument is the game number.</extracomment>
-        <translation>等级赛 第%1局</translation>
-    </message>
     <message>
         <source>Main Variation</source>
         <translation>主变例</translation>
@@ -797,49 +586,9 @@
         <source>Undo Move</source>
         <translation>撤销一步</translation>
     </message>
-    <message>
-        <source>Blue/Red</source>
-        <translation>蓝/红</translation>
-    </message>
-    <message>
-        <source>Purple</source>
-        <translation>紫色</translation>
-    </message>
-    <message>
-        <source>Green</source>
-        <translation>绿色</translation>
-    </message>
-    <message>
-        <source>Blue</source>
-        <translation>蓝色</translation>
-    </message>
-    <message>
-        <source>Yellow/Green</source>
-        <translation>黄/绿</translation>
-    </message>
-    <message>
-        <source>Orange</source>
-        <translation>橙色</translation>
-    </message>
-    <message>
-        <source>Yellow</source>
-        <translation>黄色</translation>
-    </message>
-    <message>
-        <source>Red</source>
-        <translation>红色</translation>
-    </message>
-    <message>
-        <source>Pentobi failed to generate a move.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Press back again to exit</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Untitled.blksgf</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -918,7 +667,7 @@
     </message>
     <message>
         <source>Export Image…</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1036,7 +785,7 @@
     </message>
     <message>
         <source>All files</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1282,69 +1031,322 @@
 </context>
 <context>
     <name>main</name>
+    <message>
+        <source>Pentobi</source>
+        <extracomment>Window title if no file is loaded.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Game analysis is only possible in main variation.</source>
+        <translation>棋局分析只能在主变化中进行。</translation>
+    </message>
+    <message>
+        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
+        <translation>自动保存的棋局被另一个程序实例更改。要覆盖吗？</translation>
+    </message>
+    <message>
+        <source>Your rating has increased from %1 to %2.</source>
+        <translation>您的等级从%1升到%2。</translation>
+    </message>
+    <message>
+        <source>Your rating has decreased from %1 to %2.</source>
+        <translation>您的等级从%1降到%2。</translation>
+    </message>
+    <message>
+        <source>Your rating stays at %1.</source>
+        <translation>您的等级仍然是%1。</translation>
+    </message>
+    <message>
+        <source>Delete all rating information for the current game variant?</source>
+        <translation>删除此游戏规则下的所有等级数据？</translation>
+    </message>
+    <message>
+        <source>Delete all variations?</source>
+        <translation>删除所有变例？</translation>
+    </message>
+    <message>
+        <source>Save failed.</source>
+        <translation>保存失败。</translation>
+    </message>
+    <message>
+        <source>End of tree was reached. Continue search from start of the tree?</source>
+        <translation>已经到达棋局树的最末端。从树的开头继续搜索？</translation>
+    </message>
+    <message>
+        <source>No comment found</source>
+        <translation>无注解</translation>
+    </message>
+    <message>
+        <source>%1 (modified)</source>
+        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
+        <translation>%1 （已修改）</translation>
+    </message>
+    <message>
+        <source>File has been modified by another application. Reload?</source>
+        <translation>文件被其他程序修改。重新加载吗？</translation>
+    </message>
+    <message>
+        <source>Keep only position?</source>
+        <translation>只保留棋子位置吗？</translation>
+    </message>
+    <message>
+        <source>Keep only subtree?</source>
+        <translation>只保留子树吗？</translation>
+    </message>
+    <message>
+        <source>Open failed.</source>
+        <translation>打开失败。</translation>
+    </message>
+    <message>
+        <source>Start rated game with Purple against Pentobi level %1?</source>
+        <translation>是否开始等级赛，你执紫色，对阵级别%1的电脑？</translation>
+    </message>
+    <message>
+        <source>Start rated game with Green against Pentobi level %1?</source>
+        <translation>是否开始等级赛，你执绿色，对阵级别%1的电脑？</translation>
+    </message>
+    <message>
+        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
+        <translation>是否开始等级赛，你执蓝/红，对阵级别%1的电脑？</translation>
+    </message>
+    <message>
+        <source>Start rated game with Blue against Pentobi level %1?</source>
+        <translation>是否开始等级赛，你执蓝色，对阵级别%1的电脑？</translation>
+    </message>
+    <message>
+        <source>Start rated game with Orange against Pentobi level %1?</source>
+        <translation>是否开始等级赛，你执橙色，对阵级别%1的电脑？</translation>
+    </message>
+    <message>
+        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
+        <translation>是否开始等级赛，你执黄/绿，对阵级别%1的电脑？</translation>
+    </message>
+    <message>
+        <source>Start rated game with Yellow against Pentobi level %1?</source>
+        <translation>是否开始等级赛，你执黄色，对阵级别%1的电脑？</translation>
+    </message>
+    <message>
+        <source>Start rated game with Red against Pentobi level %1?</source>
+        <translation>是否开始等级赛，你执红色，对阵级别%1的电脑？</translation>
+    </message>
+    <message>
+        <source>You have not yet played rated games in this game variant.</source>
+        <translation>在此规则下，您还没有玩过等级赛。</translation>
+    </message>
+    <message>
+        <source>Truncate this subtree?</source>
+        <translation>截断此子树？</translation>
+    </message>
+    <message>
+        <source>Truncate children?</source>
+        <translation>截断此结点下面的子结点？</translation>
+    </message>
+    <message>
+        <source>Discard game?</source>
+        <translation>丢弃本局吗？</translation>
+    </message>
+    <message>
+        <source>Pentobi %1 (level %2)</source>
+        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
+        <translation>Pentobi 版本%1（级别%2）</translation>
+    </message>
+    <message>
+        <source>Human</source>
+        <extracomment>Player name for game info in rated game.</extracomment>
+        <translation>人脑</translation>
+    </message>
+    <message>
+        <source>Rated game</source>
+        <translation>等级赛</translation>
+    </message>
+    <message>
+        <source>File has been modified by another application. Overwrite?</source>
+        <translation>文件已被其他程序修改。覆盖吗？</translation>
+    </message>
+    <message>
+        <source>%1 - Pentobi</source>
+        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Game analysis aborted</source>
+        <translation>棋局分析被取消</translation>
+    </message>
+    <message>
+        <source>Computer move aborted</source>
+        <translation>电脑行棋被取消</translation>
+    </message>
+    <message>
+        <source>Rating information deleted</source>
+        <translation>等级数据已删除</translation>
+    </message>
+    <message>
+        <source>Variations deleted</source>
+        <translation>变例已删除</translation>
+    </message>
+    <message>
+        <source>File saved</source>
+        <translation>文件已保存</translation>
+    </message>
+    <message>
+        <source>Saving image failed or unsupported image format</source>
+        <translation>图像保存失败，或不支持的图像格式</translation>
+    </message>
+    <message>
+        <source>Image saved</source>
+        <translation>图像已保存</translation>
+    </message>
+    <message>
+        <source>Creating image failed</source>
+        <translation>图像创建失败</translation>
+    </message>
+    <message>
+        <source>Continuing rated game</source>
+        <translation>继续等级赛</translation>
+    </message>
+    <message>
+        <source>Kept only position</source>
+        <translation>只保留棋子位置</translation>
+    </message>
+    <message>
+        <source>Kept only subtree</source>
+        <translation>只保留子树</translation>
+    </message>
+    <message>
+        <source>Variation is now %1</source>
+        <translation>当前变例为 %1</translation>
+    </message>
+    <message>
+        <source>Children truncated</source>
+        <translation>子结点已截断</translation>
+    </message>
+    <message>
+        <source>Setup</source>
+        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
+        <translation>设置模式</translation>
+    </message>
+    <message>
+        <source>Setup Mode</source>
+        <translation>设置模式</translation>
+    </message>
+    <message>
+        <source>Rated</source>
+        <extracomment>Label for ongoing rated game</extracomment>
+        <translation>等级赛</translation>
+    </message>
+    <message>
+        <source>Rated %1</source>
+        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
+        <translation>等级赛 第%1局</translation>
+    </message>
+    <message>
+        <source>Rated Game %1</source>
+        <extracomment>Label for rated game. The argument is the game number.</extracomment>
+        <translation>等级赛 第%1局</translation>
+    </message>
+    <message>
+        <source>Blue/Red</source>
+        <translation>蓝/红</translation>
+    </message>
+    <message>
+        <source>Purple</source>
+        <translation>紫色</translation>
+    </message>
+    <message>
+        <source>Green</source>
+        <translation>绿色</translation>
+    </message>
+    <message>
+        <source>Blue</source>
+        <translation>蓝色</translation>
+    </message>
+    <message>
+        <source>Yellow/Green</source>
+        <translation>黄/绿</translation>
+    </message>
+    <message>
+        <source>Orange</source>
+        <translation>橙色</translation>
+    </message>
+    <message>
+        <source>Yellow</source>
+        <translation>黄色</translation>
+    </message>
+    <message>
+        <source>Red</source>
+        <translation>红色</translation>
+    </message>
+    <message>
+        <source>Pentobi failed to generate a move.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Untitled.blksgf</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>computer opponent for the board game Blokus</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Set maximum level to &lt;n&gt;.</source>
         <extracomment>Description for command line option --maxlevel</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Do not use opening books.</source>
         <extracomment>Description for command line option --nobook</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Use layout optimized for smartphones.</source>
         <extracomment>Description for command line option --mobile</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Do not delay fast computer moves.</source>
         <extracomment>Description for command line option --nodelay</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Set random seed to &lt;n&gt;.</source>
         <extracomment>Description for command line option --seed</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Use &lt;n&gt; threads (0=auto).</source>
         <extracomment>Description for command line option --threads</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Print logging information to standard error.</source>
         <extracomment>Description for command line option --verbose</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>file.blksgf</source>
         <extracomment>Name of command line argument.</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Blokus SGF file to open (optional).</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>--maxlevel must be between 1 and %1</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>--seed must be a positive number</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>--threads must be a positive number</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Too many arguments</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
